@@ -66,7 +66,7 @@ Exceptions thrown by L</"open"> method could be thrown.
 
 =head2 new_from_fd
 
-C<static method new_from_fd : IO::Handle ($fd : int, $open_mode : string);>
+C<static method new_from_fd : L<IO::File|SPVM::IO::File> ($fd : int, $open_mode : string);>
 
 Creates a new L<IO::File|SPVM::IO::File> object.
 
@@ -98,24 +98,6 @@ The open mode $open_mode must be defined. Otherwise an exception is thrown.
 
 If a file is already opened, an exception is thrown.
 
-=head2 fdopen
-
-C<method fdopen : void ($fd : int, $open_mode : string);>
-
-Opens a file given the file descriptor $fd and the open mode $open_mode.
-
-This method calls L<Sys#fdopen|SPVM::Sys/"fdopen"> method.
-
-L</"FileStream"> field is set to the opened file stream.
-
-L</"InputLineNumber"> field is set to 0.
-
-Exceptions:
-
-The open mode $open_mode must be defined. Otherwise an exception is thrown.
-
-If a file is already opened, an exception is thrown.
-
 =head1 Instance Methods
 
 =head2 input_line_number
@@ -290,6 +272,24 @@ Exceptions:
 
 Exceptions thrown by L<Sys::IO#ftruncate|SPVM::Sys::IO/"ftruncate"> method could be thrown.
 
+=head2 fdopen
+
+C<protected method fdopen : void ($fd : int, $open_mode : string);>
+
+Opens a file given the file descriptor $fd and the open mode $open_mode.
+
+This method calls L<Sys#fdopen|SPVM::Sys/"fdopen"> method.
+
+L</"FileStream"> field is set to the opened file stream.
+
+L</"InputLineNumber"> field is set to 0.
+
+Exceptions:
+
+The open mode $open_mode must be defined. Otherwise an exception is thrown.
+
+If a file is already opened, an exception is thrown.
+
 =head1 See Also
 
 =over 2
