@@ -10,10 +10,15 @@ SPVM::IO::Handle - I/O Handling
 
 IO::Handle class in L<SPVM> has methods to handle file handles.
 
+=head1 Details
+
+IO::Handle class is an abstract class.
+
+See L</"Well Known Child Classes"> about its child classes.
+
 =head1 Usage
   
   use IO::Handle;
-  my $handle = IO::Handle->new;
 
 =head1 Details
 
@@ -41,11 +46,13 @@ A flag for blocking IO.
 
 =head1 Class Methods
 
-=head2 new
+=head1 Instance Methods
 
-C<static method new : L<IO::Handle|SPVM::IO::Handle> ($options : object[]);>
+=head2 init
 
-Creates a new L<IO::Handle|SPVM::IO::Handle> object, and returns it.
+C<protected method init : void ($options : object[] = undef);>
+
+Initializes fields given the options $options.
 
 Options:
 
@@ -65,14 +72,8 @@ L</"Blocking"> field is set to this value.
 
 If this value is 0, L</"set_blocking"> method is called with 0.
 
-=item * C<FieldsInitOnly : Int = 0>
-
-If this value is 1, only initialization of fields are performed without system calls for the file descriptor L</"FD">.
-
 =back
 
-=head1 Instance Methods
-
 =head2 fileno
 
 C<method fileno : int ();>
